
// Dialog/4x driver function codes
#define  F_SSTART    1         // System start
#define  F_SPARMS    2         // Set global parameters
#define  F_SSTOP     3         // System stop
#define  F_CHSTOP    4         // Channel stop
#define  F_CHSTAT    5         // Get channel status block
#define  F_SETH      6         // Set hook switch
#define  F_SETCST    7         // Set CST mask
#define  F_CLRDT     8         // Clear dtmf buffer
#define  F_GETDT     9         // Get dtmf digit
#define  F_RECB      10        // Record to buffer
#define  F_PLAYB     11        // Playback from buffer
#define  F_RECF      12        // Record to file
#define  F_PLAYF     13        // Playback from file
#define  F_DIAL      14        // Dial string
#define  F_GETDTS    15        // Get dtmf string
#define  F_GETEVT    16        // Get next event
#define  F_SCHED     18        // Scheduler time slice
#define  F_XPLAYF    19        // Extended play function
#define  F_PLAYGTG   20        // General tone generation
#define  F_TNINFO    21        // Get tone info
#define  F_TNFLUSH   22        // Flush tone info buffer
#define  F_GETCAR    27        // Get the Call Analysis Results
#define  F_SXPARM    28        // Set ext'd shared ram parms funct
#define  F_SCPARM    29        // Set channel parameters
#define  F_CALL      30        // Call a numbr using call analysis
#define  F_SETD      31        // Set the digit control mask
#define  F_GETVER    32        // Get the current driver vers numb
#define  F_PLAYUB    34        // Playback from a users envir bufr
#define  F_RECUB     35        // Record to a users envir buffer
#define  F_GETCOM    36        // Get the comm area
#define  F_PUTCOM    37        // Put the comm area
#define  F_STPARM    38        // Set channel parameter
#define  F_WINK      39        // Perform wink command
#define  F_ROUTETS   40        // Perform timeslot routing
#define  F_ADDTONE   43        // Add current tone to channel
#define  F_BUILDTONE 44        // Build temporary tone
#define  F_DELTONES  45        // Delete all tones from channel
#define  F_TNSTAT    46        // Enable/disable tones
#define  F_XCALL     47        // Call number(call analysis w/term)
#define  F_ADJSV     48        // Adjust S/V conditions
#define  F_SETSVCOND 49        // Set S/V adjustment conditions
#define  F_CLRSVCOND 51        // Clear S/V adjust conditions
#define  F_GETCURSV  52        // Get S/V adjustment conditions
#define  F_SETSVMT   53        // Update S/V modification table
#define  F_GETSVMT   54        // Read S/V modification table
#define  F_READQUAL  55        // Read qualification template
#define  F_UPDQUAL   56        // Write qualification template
#define  F_CHGCALLP  57        // Change Call Analysis tones
#define  F_SERNUM    59        // Get the Serial number
#define  F_LISTEN    60        // Get the Serial number
#define  MAXFCN      60        // Max(last) Dialog\4x fcn number

#define  MINMFCN     80        // Min(first) AMX8x fcn number
#define  F_MSTART    80        // Start all AMX8x boards
#define  F_MOFF      81        // Disconnect all AMX8x switches
#define  F_MMK       82        // Connect the specified AMX8x chs
#define  F_MBRK      83        // Disconnect the specified AMX8 ch
#define  F_MMASK     84        // Set AMX8x mask for a channel
#define  F_MSTOP     85        // Stop all AMX8x boards
#define  F_RSTART    86        // Start ringing an AMX8 connection
#define  F_RSET      87        // Set AMX81 ring parms for a conn
#define  MAXMFCN     87        // Max(last) AMX8x fcn number

#define  MINID       129       // Min AMX8x telephone station ID

// Values for STATUS byte in the CSB
#define  S_STOP      0         // Channel is stopped
#define  S_RECORD    1         // Channel is in record mode
#define  S_PLAY      2         // Channel is in playback mode
#define  S_GETDTS    3         // Channel is getting a DTMF string
#define  S_OFFH      4         // Channel is waiting for offhook
#define  S_DIAL      5         // Channel is dialing
#define  S_ONH       6         // Channel is waiting for onhook
#define  S_CALL      7         // Channel is in call analysis stat
#define  S_PARM      8         // Channel parameter is being upd
#define  S_WINK      9         // Channel is waiting for wink cmpl
#define  S_PLAYGTG   10        // Channel is waiting for tone cmpl

// Hook states
#define  H_OFFH      0         // Off hook.
#define  H_ONH       1         // On hook.

// Values for termination types (last_term) and event type
#define  T_NOTERM    0         // No termination received
#define  T_MAXDT     1         // Maximum DTMF digits received
#define  T_TERMDT    2         // Terminating DTMF digit received
#define  T_STOP      3         // User stop
#define  T_DOSERR    4         // Dos error
#define  T_MAXBYT    5         // Max bytes reached on play or rec
#define  T_HFAIL     6         // Hardware failure
#define  T_TIME      7         // Multi-tasking function timed out
#define  T_OFFH      8         // Offhook complete
#define  T_DIAL      9         // Dialing complete
#define  T_SIL       10        // Maximum silence received
#define  T_EOF       11        // Eof reached on playback
#define  T_LCTERM    12        // Terminate by drop in loop signal
#define  T_DFULL     13        // Disk full
#define  T_ONH       14        // Onhook complete
#define  T_MDTERM    17        // AMX80 disconnect termination
#define  T_CATERM    18        // Call analysis termination
#define  T_LCREV     19        // Loop signal battery reversal
#define  T_LC        20        // Loop signal drop event
#define  T_RING      21        // Rings received
#define  T_SILOFF    22        // Silence off
#define  T_SILON     23        // Silence on
#define  T_AMXCON    24        // AMX8x channel connect
#define  T_AMXDIS    25        // AMX8x channel disconnect
#define  T_LCON      26        // Loop signal on event
#define  T_MAXRNG    27        // Max rings reached on AMX81 conn
#define  T_MCTERM    28        // Rings termiated by AMX8 connect
#define  T_MDTMF     29        // Terminated by masked DTMF digit
#define  T_IDTIME    30        // Interdigit delay exceeded
#define  T_NSIL      31        // Terminated by a max non-silence
#define  T_BUFFUL    32        // Termination from EMS buffer full
#define  T_BUFEMP    33        // Terminated from EMS buffer empty
#define  T_EMSERR    34        // Terminated by EMS error
#define  T_EMSLOW    35        // EMS buffer low
#define  T_EMSHI     36        // EMS buffer high
#define  T_STPARM    37        // Parameter updated
#define  T_WINK      38        // Wink protocol complete
#define  T_WKRECV    39        // Wink received
#define  T_DTMF      40        // DTMF digit received
#define  T_TONEON    41        // Tone on detect
#define  T_TONEOFF   42        // Tone off detect
#define  T_BADTERM   43        // Invalid termination condition
#define  T_MTONEON   44        // Terminated by Tone On
#define  T_MTONEOFF  45        // Terminated by Tone Off
#define  T_CAERROR   46        // Call progress error
#define  T_TGERR     47        // Tone generation template error
#define  T_TGCMPLT   48        // Tone generation complete
#define  T_ADSIERR   49        // ADSI protocol failure
#define  MAXTERM     49        // Max(last) termination type

// Values for system mode
#define  SM_POLL     0         // Polled mode.
#define  SM_EVENT    1         // Event driven mode.

// Equates for error (return) codes
#define  E_SUCC      0         // Function was successful
#define  E_FAILST    1         // Board failed self test
#define  E_NODT      2         // Dtmf buffer empty
#define  E_SACT      3         // System already active
#define  E_SNACT     4         // System not active
#define  E_BADDL     5         // D4x hardware error
#define  E_BADFCN    6         // Invalid function code requested
#define  E_BADINT    7         // Interrupt level not available
#define  E_BADDCB    8         // DCB parmameter error
#define  E_BADCH     9         // Invalid channel number
#define  E_MTACT     10        // Multitasking func already active
#define  E_MTNACT    11        // Multitasking function not active
#define  E_BADPAR    12        // Bad parameter
#define  E_BADVER    13        // Incorrect version of firmware
#define  E_NOTIMP    14        // Function not implemented/avail
#define  E_NOTERM    15        // Terminating cond not specified
#define  E_NOMEM     16        // Insufficent buffer mem available
#define  E_DOSERR    24        // DOS error (DOS error code in al)
#define  E_DSKCNT    25        // Error in data read/wrote to disk
#define  E_NOAMX     26        // No AMX8x boards present
#define  E_AMXON     27        // AMX 8xs already started
#define  E_AMXOFF    28        // AMX 8xs already stopped
#define  E_BADXY     29        // Invalid X,Y coordinate
#define  E_BADPRT    30        // Bad AMX8x tel. station ID specified
#define  E_BADCUR    31        // Bad cursor position specified
#define  E_EMSSW     32        // EMM not installed or corrupted
#define  E_EMSERR    33        // EMM reported error
#define  E_NOVBUF    34        // No buffer alloc for EMS ram disk
#define  E_TSBADSLOT 35        // Bad timeslot number
#define  E_TIMEOUT   36        // Timer expired
#define  E_BADPROD   37        // Not supported by this product
#define  E_TONEID    38        // Bad tone template id
#define  E_TNPARM    39        // Invalid param in tone template
#define  E_MAXTMPLT  40        // Max tone detection templates
#define  E_MAXSVCB   41        // Invalid number of SVCB blocks
#define  E_SVMTTYPE  42        // Invalid table type specified
#define  E_SVMTRANGE 43        // Entry in SVMT was out of range
#define  E_BADSVCB   44        // Invalid SV condition block(SVCB)
#define  E_BADADJSIZ 45        // Invalid SV adjustment size
#define  E_QUALID    46        // bad qualification template id
#define  E_TNINFO    80        // not enough tone information to do the learning
#define  E_INVALID   81        // lm_classify() cannot determine if single or dual tone
#define  E_FRAMES    82        // Invalid number of frames (lm_frames) in LM_PARM
#define  E_CONTIM    83        // Invalid continuous tone minimum on-time (lm_cnt_min) in LM_PARM
#define  E_CADFLAG   84        // Invalid continuous/cadence flag (lm_cadflag) in LM_PARM
#define  E_LNPARM    85        // Invalid parameters in LM_PARM
#define  E_AMP       86        // Invalid tone amplitude in TN_AMP
#define  E_METHOD    88        // Invalid learning method (lm_method) in LM_PARM
#define  E_FTOLE     89        // Invalid frequency tolerance (lm_frq_tol) in LM_PARM
#define  E_DTOLE     90        // Invalid duration tolerance (lm_dur_tol) in LM_PARM
#define  E_DFLAG     91        // Invalid dual/single tone flag (dflagp)

// Following errors are defined by PDC, associated error messages will be
// displayed by pd_error(), Dialogic functions do not know about these
#define  E_BADSEEK   100       // file seek unsuccessful
#define  E_NOHANDLE  101       // no file handle present
#define  E_BADCLOSE  102       // file close unsuccessful
#define  E_BADOPEN   103       // file open unsuccessful

// Equates for cst_mask
#define  C_LC         1        // Loop signal drop     0x01
#define  C_RING       2        // Rings received       0x02
#define  C_SILOFF     4        // Silence off          0x04
#define  C_SILON      8        // Silence on           0x08
#define  C_OFFH      16        // Offhook complete     0x10
#define  C_ONH       32        // Onhook complete      0x20
#define  C_LCON      64        // Loop signal on       0x40
#define  C_WKRECV   128        // Recv incoming wink   0x80
#define  C_LCREV    256        // Loop signal reversal 0x100

// Equates for set parameter function
#define  CH_WKDLY   516        // Delay before sending wink  0x204
#define  CH_WKOUT   517        // Duration of outgoing wink  0x205
#define  CH_WKMIN   518        // Min on for wink detection  0x206
#define  CH_WKMAX   519        // Max on for wink detection  0x207

#define  RATE_PLAY  3585       // Parm id for playback sampling rate  0x0E01
#define  RATE_REC   3586       // Parm id for record sampling rate    0x0E02
#define  WALLPARM   3587       // Parm id for wall parameter          0x0E03

#define  CH_MINREVON   1049    // Min LC reversal on time  0x419
#define  CH_MINREVOFF  1049    // Min LC reversal off time 0x419
                              
#define  SR_6K      6000       // Parm value for 6KHz
#define  SR_8K      8000       // Parm value for 8KHz

// Equates for digit_ctl_mask
#define  D_DTMF      1         // DTMF digit detection enable
#define  D_LPD       2         // Loop pulse digit detect enabled
#define  D_DPDZ      8         // Dial pulse detection with zero training
#define  D_DPD       16        // Dial pulse detection without zero training

// Equates for digit_ctl_type
#define  DT_FLUSH    1         // Flush dtmf digit buffer
#define  DT_QUEUE    2         // Put dtmf digits onto event queue

// Equates for channel error conditions
#define  X_NOERR     0         // No error
#define  X_BUFERR    1         // Error occurred

// Record mode types  (bit mapped)
#define  RM_NORM      0        // Normal record
#define  RM_SCOMP     1        // Compress sil. from incoming data
#define  RM_RDISK     4        // I/O from an EMS ram disk
#define  RM_ALAW     16        // Record A-law data
#define  RM_ADPCM     0        // ADPCM encoding
#define  RM_PCM     256        // Mu Law PCM mode     0x100
#define  RM_SR8     512        // 8KHz sampling rate  0x200
#define  RM_NOAGC  1024        // turn off AGC        0x400
#define  RM_SR6    2048        // 6KHz sampling rate  0x800

// Play mode types   (bit mapped)
#define  PM_NORM      0        // Normal playback
#define  PM_NDX       1        // Indexed playback
#define  PM_RDISK     4        // I/O from an EMS ram disk
#define  PM_FILES     8        // Multiple file handles for index play
#define  PM_ALAW     16        // Play A-law data
#define  PM_ADPCM     0        // ADPCM encoding
#define  PM_PCM     256        // Mu Law PCM mode     0x100
#define  PM_SR8     512        // 8KHz sampling rate  0x200
#define  PM_SR6    2048        // 6KHz sampled file   0x800
#define  PM_ADSI   8192        // ADSI data transfer  0x2000
#define  PM_RAW   16384        // Raw PCM mode        0x4000

// Bit mask for rwb_flags in RWB
#define  RW_DINIT     1        // Touch tone initiation on/off
#define  RW_TONE      2        // Tone before rec/playback on/off
#define  RW_DELAY     4        // Inter-digit delay starts on first digit
#define  RW_10MSEC    8        // 10 msec unit for maxsec (-y option)
#define  RW_100MSEC  16        // 100 msec unit for maxsec (-y option)

// Bit mask for AMX8x event mask
#define  A_CON       1         // AMX8x connect (pickup)
#define  A_DIS       2         // AMX8x disconnect (hangup)

// Bit mask for line status register
#define  LS_CARNG    4         // Call analysis detecting ring     0x04
#define  LS_HOOK     8         // Hook status bit                  0x08
#define  LS_RING     16        // Ring current bit                 0x10
#define  LS_LOOP     32        // Loop current bit                 0x20
#define  LS_TT       64        // Touch tone is waiting to be read 0x40
#define  LS_SIL      128       // Silence bit                      0x80

// Call Analysis termination data types/call status values
#define  CA_BUSY         7     // Called line is busy
#define  CA_NOAN         8     // Called line did not answer
#define  CA_NORNG        9     // Called line did not ring
#define  CA_CONN        10     // Called line connected
#define  CA_OPINT       11     // Called line recvd oper intercept
#define  CA_NODIALTONE  17     // Called line recvd no dialtone
#define  CA_FAXTONE     18     // Called line recvd fax tone

// Call Analysis connection type
#define  CON_CAD     1         // Cadence break
#define  CON_LPC     2         // Loop current drop
#define  CON_PVD     3         // Positive Voice Detection
#define  CON_PAMD    4         // Positive Answering Machine Detection

// Call Analysis CPB intflg
#define  OPTEN       1         // Enable operator intercept w/connect
#define  OPTDIS      2         // Disable operator
#define  OPTCON      3         // Enable operator intercept w/o connect
#define  PVD_ENABLE  4         // Enable Positive Voice Detection(PVD)
#define  PVD_OPTEN   5         // Enable PVD + OPTEN
#define  PVD_OPTCON  6         // Enable PVD + OPTCON
#define  PAMD_ENABLE 7         // Enable PAMD w/ no Operator intercept
#define  PAMD_OPTEN  8         // Enable PAMD with Operator intercept

// Call Analysis error codes
#define  MEMERR      1         // Out of memory trying to create SIT
#define  TMOUTON     2         // Timeout waiting for a SIT tone
#define  TMOUTOFF    3         // SIT tone too long
#define  UNEXPTN     4         // Unexpected SIT tone
#define  MAXFRQERR   5         // Invalid mxtimefrq field in CPB
#define  UPFRQERR    6         // Invalid upper frequency selection
#define  LGTUERR     7         // Lower frequency > upper frequency
#define  OVRLPERR    8         // Overlap in selected SIT tones

// Masked DTMF termination/initiation equates
#define  DM_D        1         // Mask for DTMF d.  0x0001
#define  DM_1        2         // Mask for DTMF 1.  0x0002
#define  DM_2        4         // Mask for DTMF 2.  0x0004
#define  DM_3        8         // Mask for DTMF 3.  0x0008
#define  DM_4        16        // Mask for DTMF 4.  0x0010
#define  DM_5        32        // Mask for DTMF 5.  0x0020
#define  DM_6        64        // Mask for DTMF 6.  0x0040
#define  DM_7        128       // Mask for DTMF 7.  0x0080
#define  DM_8        256       // Mask for DTMF 8.  0x0100
#define  DM_9        512       // Mask for DTMF 9.  0x0200
#define  DM_0        1024      // Mask for DTMF 0.  0x0400
#define  DM_S        2048      // Mask for DTMF *.  0x0800
#define  DM_P        4096      // Mask for DTMF #.  0x1000
#define  DM_A        8192      // Mask for DTMF a.  0x2000
#define  DM_B        16384     // Mask for DTMF b.  0x4000
#define  DM_C        32768     // Mask for DTMF c.  0x8000

// Speed and Volume(S/V) Control
#define  SV_SPEEDTBL   1       // Modify speed   0x01
#define  SV_VOLUMETBL  2       // Modify volume  0x02

#define  SV_ABSPOS     0       // Absolute position                        0x00
#define  SV_RELCURPOS  16      // Relative position from current position  0x10
#define  SV_TOGGLE     32      // Toggle                                   0x20
                       
#define  SV_WRAPMOD    1       // S/V Modification Table wraparound enable 0x001
#define  SV_SETDEFAULT 2       // Reset to default S/V Modification Table  0x002
#define  SV_LEVEL      16      // Digit level sensitive                    0x010
#define  SV_BEGINPLAY  32      // Apply play adjustment at beginning of    0x020
                               // each playback

// S/V toggle modes for Play Adjustment Conditions
#define  SV_TOGORIGIN  0       // Toggle between origin and last modified position         0x00
#define  SV_CURORIGIN  1       // Reset current position to the origin                     0x01
#define  SV_CURLASTMOD 2       // Reset current position to last modified position         0x02
#define  SV_RESETORIG  3       // Reset current position and last modified state to origin 0x03

// S/V defines for dl_addspddig()
#define  SV_ADD10PCT      1    // Speed up playback 10 percent
#define  SV_ADD20PCT      2    // Speed up playback 20 percent
#define  SV_ADD30PCT      3    // Speed up playback 30 percent
#define  SV_ADD40PCT      4    // Speed up playback 40 percent
#define  SV_ADD50PCT      5    // Speed up playback 50 percent
#define  SV_SUB10PCT     -1    // Slow down playback 10 percent
#define  SV_SUB20PCT     -2    // Slow down playback 20 percent
#define  SV_SUB30PCT     -3    // Slow down playback 30 percent
#define  SV_SUB40PCT     -4    // Slow down playback 40 percent
#define  SV_SUB50PCT     -5    // Slow down playback 50 percent
#define  SV_NORMAL      255    // Set playback to normal speed/vol 0xFF

// S/V defines for dl_addvoldig()
#define  SV_ADD2DB        1    // Increase volume of playback 2dB
#define  SV_ADD4DB        2    // Increase volume of playback 4dB
#define  SV_ADD6DB        3    // Increase volume of playback 6dB
#define  SV_ADD8DB        4    // Increase volume of playback 8dB
#define  SV_SUB2DB       -1    // Decrease volume of playback 2dB
#define  SV_SUB4DB       -2    // Decrease volume of playback 4dB
#define  SV_SUB6DB       -3    // Decrease volume of playback 6dB
#define  SV_SUB8DB       -4    // Decrease volume of playback 8dB

// Tone definitions for Call Analysis
#define  TID_FIRST     250
#define  TID_DIAL_LCL  250
#define  TID_DIAL_INTL 251
#define  TID_DIAL_XTRA 252
#define  TID_BUSY1     253
#define  TID_RNGBK1    254
#define  TID_BUSY2     255
#define  TID_RNGBK2    256
#define  TID_FAX1      258
#define  TID_FAX2      259
#define  TID_LAST      259

// PAMD decision type (spdval field of the CPB)
#define  PAMD_FULL     1      // Wait for full decision (after ansrsize)
#define  PAMD_QUICK    2      // Decide as soon as voice decides

#define  PAMD_QUAL1TMP 11     // PAMD Qualifcation template
#define  PAMD_QUAL2TMP 12     // PAMD Qualifcation template

// Call Analysis Tone classes
#define  TNTYP_RNGBACK   1     // Ringback Class
#define  TNTYP_BUSY      2     // Busy Class
#define  TNTYP_FAX       3     // FAX tone Class

// Battery Reversal equates
#define  LC_NORM2REV     0
#define  LC_REV2NORM     1

// pd_getcstat() definitions
#define CS_CSTMASK   1
#define CS_STATUS    2
#define CS_CHERR     3
#define CS_MTFCN     4
#define CS_LASTTERM  5
#define CS_BUFCNTH   6
#define CS_BUFCNT    7
#define CS_DTMFRCVD  8
#define CS_DOSERR    9
#define CS_LINESTAT  10
#define CS_CALLSTAT  11
#define CS_INTRFREQ  12
#define CS_DIG_MASK  13

// File open definitions
#define VH_READ      0         // Open file for playing
#define VH_RDWR      1         // Open file for playing or recording
#define VH_CREATE    2         // Open file for recording, overwrite existing
#define VH_APPEND    3         // Open file for recording, append to existing

// File seek definitions
#define VH_SET        0        // Seek from beginning of file
#define VH_RELATIVE   1        // Seek from current pointer position
#define VH_END        2        // Seek from end of file

// Driver active query definitions
#define DV_NONE       0        // Driver is not installed
#define DV_ACTIVE     1        // Driver is installed
#define DV_NOBOARD    2        // Driver is installed with no D/4x board present

// Play modes for play number
#define PN_DOLLARS '$'         // '$' plays dollars and cents
#define PN_NUMBER  '9'         //       (1 hundred 24 dollars and 42 cents)
#define PN_DIGITS  'D'         // '9' plays as a number only   (1 hundred 24)
#define PN_GALLONS 'G'         // 'D' plays digits separately  (1 2 4 point 4 2)
                               // 'G' plays gallons
                               //       (1 hundred 24 gallons point 42)

#xcommand ANSWER CHANNEL <nChannel> => ;
          pd_setHook( <nChannel>, H_OFFH )

#xcommand CLEAR CHANNEL <nChannel> BUFFER => ;
          pd_clrDTMF( <nChannel> )

#xcommand HANG UP CHANNEL <nChannel> => ;
          pd_setHook( <nChannel>, H_ONH)

#xcommand SET MAX DTMF TO <nMaxDigits> => ;
          pd_global('maxdtmf', <nMaxDigits> )

#xcommand SET MAX SECS TO <nMaxSeconds> => ;
          pd_global('maxsec', <nMaxSeconds> )

#xcommand SET MAX SILENCE TO <nMaxSeconds> => ;
          pd_global('maxsil', <nMaxSeconds>)

#xcommand SET TERMINATING CHARACTER TO <cDTMFCharacter> => ;
          pd_global('termdtmf', <cDTMFCharacter> )

#xcommand START VOICE AT IRQ <nHardwareInterrupt> WITH <nMaxChannels> ;
             MASK <nCstMask> RINGS <nRings> =>;
          pd_init(<nHardwareInterrupt>, <nMaxChannels>, <nCstMask>, <nRings> )


#xcommand STOP VOICE => ;
          pd_deinit()

#xcommand NO TERMINATE ON LOOP SIGNAL => ;
          pd_global('loopsig', 0)

#xcommand TERMINATE ON LOOP SIGNAL => ;
          pd_global('loopsig', 1)

#xcommand SET TONE TO <nMiliSeconds> => ;
          pd_setTone( <nMiliSeconds> )
